@@ -71,7 +71,7 @@ def getModuleTest(inspectGlobals, logResult, globalsInstance) :
             , wrapperStatus = globalsInstance.wrapperStatus
             , testStatus = globalsInstance.testStatus
             , logStatus = globalsInstance.logStatus
-            # , logsWithColors = globalsInstance.logsWithColors and SettingHelper.activeEnvironmentIsLocal()
+            , logsWithColors = globalsInstance.logsWithColors or SettingHelper.activeEnvironmentIsLocal()
         )
         LogHelper.test(tddModule, f'{testName} started')
         testReturns = {}
@@ -184,7 +184,7 @@ def run(
     wrapperStatus = False,
     testStatus = False,
     logStatus = False,
-    # logsWithColors = True,
+    logsWithColors = True,
     inspectGlobals = False,
     logResult = True
 ) :
@@ -201,7 +201,7 @@ def run(
         , wrapperStatus = wrapperStatus
         , testStatus = testStatus
         , logStatus = logStatus
-        # , logsWithColors = logsWithColors and SettingHelper.activeEnvironmentIsLocal()
+        , logsWithColors = logsWithColors or SettingHelper.activeEnvironmentIsLocal()
     )
     testModuleNames, testsToRun, runSpecificTests = getTestModuleNames(runOnly, ignore, globalsInstance)
     returns = {}
@@ -286,7 +286,7 @@ def getTestEnvironmentVariables(globalsInstance) :
         LogHelper.WRAPPER : globalsInstance.wrapperStatus,
         LogHelper.ERROR : globalsInstance.errorStatus,
         LogHelper.TEST : globalsInstance.testStatus,
-        # LogHelper.ENABLE_LOGS_WITH_COLORS: globalsInstance.logsWithColors
+        LogHelper.ENABLE_LOGS_WITH_COLORS: globalsInstance.logsWithColors
     }
 
 def getGlobalsTestKwargs(inspectGlobals, globalsInstance) :
